@@ -229,7 +229,7 @@ class poi():
                 self.multiframe_nt_seq.append(self.nt_seq[n:-(3-n)])
         
         cd = CodonDictionaries()
-        smm = SequenceManipMethods()
+        smm = SequenceManipMethods.SequenceManipMethods()
         codons_aa_seq = smm.nt2aa(codons_seq)
         
         for frame in self.multiframe_nt_seq:
